@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.050_03';
+our $VERSION = '0.051_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -168,8 +168,10 @@ sub __almanac_event_type_iterator {
 
     my $inx = 0;
 
+    my $horizon = $station->__get_almanac_horizon();
+
     my @events = (
-	[ $station, next_elevation => [ $self, 0, 1 ], 'horizon',
+	[ $station, next_elevation => [ $self, $horizon, 1 ], 'horizon',
 		[ 'Moon set', 'Moon rise' ] ],
 	[ $station, next_meridian => [ $self ], 'transit',
 		[ undef, 'Moon transits meridian' ] ],
